[Pcsclite-cvs-commit] r3337 - /trunk/Drivers/ccid/src/ifdhandler.c

rousseau at users.alioth.debian.org rousseau at users.alioth.debian.org
Sat Mar 7 14:30:18 UTC 2009


Author: rousseau
Date: Sat Mar  7 14:30:17 2009
New Revision: 3337

URL: http://svn.debian.org/wsvn/pcsclite/?sc=1&rev=3337
Log:
IFDHSetProtocolParameters(): rename atr in openpgp_atr

ifdhandler.c:822: warning: declaration of ‘atr’ shadows a previous local
ifdhandler.c:527: warning: shadowed declaration is here

Modified:
    trunk/Drivers/ccid/src/ifdhandler.c

Modified: trunk/Drivers/ccid/src/ifdhandler.c
URL: http://svn.debian.org/wsvn/pcsclite/trunk/Drivers/ccid/src/ifdhandler.c?rev=3337&op=diff
==============================================================================
--- trunk/Drivers/ccid/src/ifdhandler.c (original)
+++ trunk/Drivers/ccid/src/ifdhandler.c Sat Mar  7 14:30:17 2009
@@ -818,12 +818,12 @@
 				param[3] = atr.ib[i][ATR_INTERFACE_BYTE_TB].value;
 
 				{
-					/* Hack for OpenGPG card */
-					char atr[] = { 0x3B, 0xFA, 0x13, 0x00, 0xFF, 0x81,
+					/* Hack for OpenPGP card */
+					char openpgp_atr[] = { 0x3B, 0xFA, 0x13, 0x00, 0xFF, 0x81,
 						0x31, 0x80, 0x45, 0x00, 0x31, 0xC1, 0x73, 0xC0,
 						0x01, 0x00, 0x00, 0x90, 0x00, 0xB1 };
 
-					if (0 == memcmp(ccid_slot->pcATRBuffer, atr,
+					if (0 == memcmp(ccid_slot->pcATRBuffer, openpgp_atr,
 						ccid_slot->nATRLength))
 						/* change BWI from 4 to 7 to increase BWT from
 						 * 1.4s to 11s and avoid a timeout during on




More information about the Pcsclite-cvs-commit mailing list